@@ -450,6 +450,7 @@ GtkActionEntry kz_actions_popup[] =
 
 	{"StockEncodingMenu", NULL, N_("_Encoding"), NULL, NULL, NULL},
 	{"StockTabList",      NULL, N_("_TabList"),  NULL, NULL, NULL},
+	{"StockOpenSmartBookmark",      NULL, N_("Open Smartbookmark by selected text"),  NULL, NULL, NULL},
 };
 
 const gint kz_actions_popup_len = G_N_ELEMENTS(kz_actions_popup);
@@ -887,7 +888,7 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 		   sizeof(extra_menu_path), "%s/CopyInUserFormat", path);
 
 	extra_menu = GET_MENU(kz, extra_menu_path);
-	if(extra_menu)
+	if (extra_menu)
 	{
 		KzTabLabel *kztab;
 		kztab = KZ_TAB_LABEL(kz_window_get_tab_label(kz, KZ_WINDOW_CURRENT_PAGE(kz)));
@@ -900,7 +901,7 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 		   sizeof(extra_menu_path), "%s/EncodingMenu", path);
 
 	extra_menu = GET_MENU(kz, extra_menu_path);
-	if(extra_menu) 
+	if (extra_menu)
 	{
 		kz_actions_popup_append_encoding_menuitem
 			(kz, GTK_MENU_ITEM(extra_menu));
@@ -910,11 +911,21 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 	g_snprintf(extra_menu_path,
 		   sizeof(extra_menu_path), "%s/TabList", path);
 	extra_menu = GET_MENU(kz, extra_menu_path);
-	if(extra_menu) 
+	if (extra_menu)
 	{
 		kz_actions_popup_append_tablist_menuitem(kz, extra_menu);
 	}
 
+        /* add smart bookmark menu*/
+	g_snprintf(extra_menu_path,
+		   sizeof(extra_menu_path), "%s/OpenSmartBookmark", path);
+	extra_menu = GET_MENU(kz, extra_menu_path);
+	if (extra_menu)
+	{
+		kz_actions_dynamic_append_open_smart_bookmark_menuitem
+			(kz, GTK_MENU_ITEM(extra_menu));
+	}
+
 	g_signal_connect(popup_menu, "hide",
 			 G_CALLBACK(cb_popup_menu_hide), kz);
 	gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
