@@ -136,7 +136,7 @@ act_tab_close_right (GtkAction *action, KzWindow *kz)
 }
 
 static void
-act_tab_close_all_without_active (GtkAction *action, KzWindow *kz)
+act_tab_close_all_inactive_active (GtkAction *action, KzWindow *kz)
 {
 	close_all_tab(action, kz, 0);
 }
@@ -182,6 +182,44 @@ act_tab_close_all_child (GtkAction *action, KzWindow *kz)
 	g_list_free(list);
 }
 
+static void
+act_tab_close_all_same_site (GtkAction *action, KzWindow *kz)
+{
+	KzTabLabel *kztab;
+	GtkNotebook *notebook;
+	gint num;
+	gint i;
+	gchar **src;
+	gchar **target;
+
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
+
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+	notebook = GTK_NOTEBOOK(kztab->kz->notebook);
+	num = gtk_notebook_get_n_pages(notebook);
+	if (num < 2) return;
+
+	src = g_strsplit(kz_embed_get_location(KZ_EMBED(kztab->kzembed)),
+			"/", 0);
+
+	for (i = num - 1; i >= 0; i--)
+	{
+		GtkWidget *widget = KZ_WINDOW_NTH_PAGE(kz, i);
+		kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(kz->notebook),
+							widget));
+		target = g_strsplit(kz_embed_get_location(KZ_EMBED(kztab->kzembed)),
+				"/", 0);
+
+		if(!(strcmp(src[2] , target[2])))
+		{
+			kz_window_close_tab(kz, widget);
+		}
+		g_strfreev(target);
+	}
+	g_strfreev(src);
+}
 
 static void
 act_tab_copy_title (GtkAction *action, KzWindow *kz)
@@ -276,6 +314,7 @@ act_tab_toggle_javascript (GtkAction *action, KzWindow *kz)
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
 
 	kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), active);
+	kz_tab_label_set_javascript(kztab, active);
 }
 
 static void
@@ -335,12 +374,15 @@ GtkActionEntry kz_actions_tab[] =
 	{"TabCloseAllForward", KZ_STOCK_CLOSE_FORWARD, N_("Close all _forward tabs"), 
 	 NULL, NULL, G_CALLBACK(act_tab_close_right)},
 
-	{"TabCloseAllWithoutActive", GTK_STOCK_CLOSE, N_("Close all with_out this tab"),
-	 NULL, NULL, G_CALLBACK(act_tab_close_all_without_active)},
+	{"TabCloseAllInactiveTabs", GTK_STOCK_CLOSE, N_("Close all _inactive tabs"),
+	 NULL, NULL, G_CALLBACK(act_tab_close_all_inactive_active)},
 
 	{"TabCloseAllChild", GTK_STOCK_CLOSE, N_("Close all c_hild tab"),
 	 NULL, NULL, G_CALLBACK(act_tab_close_all_child)},
 
+	{"TabCloseAllSameSiteAsThis", GTK_STOCK_CLOSE, N_("Close all tabs which _open the same site as this"),
+	 NULL, NULL, G_CALLBACK(act_tab_close_all_same_site)},
+
 	{"TabCopyTitle",        NULL, N_("Copy _Title"),
 	 NULL, NULL, G_CALLBACK(act_tab_copy_title)},
 
@@ -451,7 +493,7 @@ set_popup_menu_sensitive (KzTabLabel *kztab)
 	g_object_set(action, "sensitive", !(pos == num -1), NULL);
 
 	action = gtk_action_group_get_action(kz->tabpop_actions,
-					     "TabCloseAllWithoutActive");
+					     "TabCloseAllInactiveTabs");
 	g_object_set(action, "sensitive", num > 1, NULL);
 
 	action = gtk_action_group_get_action(kz->tabpop_actions,
@@ -510,10 +552,10 @@ kz_actions_tab_popup_menu_modal (KzTabLabel *kztab, guint button, guint time)
 	/* add available feeds */
 	extra_menu = gtk_ui_manager_get_widget(kztab->kz->menu_merge,
 					       "/TabPopup/TabAddFeedBookmark");
-	if(extra_menu)
+	if (extra_menu)
 	{
 		kz_actions_dynamic_append_add_feed_bookmark
-			(kztab->kzembed, GTK_MENU_ITEM(extra_menu));
+			(kztab->kz, GTK_MENU_ITEM(extra_menu));
 	}
 
 	set_popup_menu_sensitive(kztab);
