@@ -1938,6 +1938,7 @@ GtkActionEntry kz_actions[] =
   {"StockSidebarPosMenu",     NULL, N_("Sidebar position"),  NULL, NULL, NULL},
   {"StockInputMethodMenu",    NULL, N_("Input Methods"),     NULL, NULL, NULL},
   {"StockSessionMenu",        NULL, N_("Session"),           NULL, NULL, NULL},
+  {"StockExtensionMenu",      NULL, N_("Extension"),   NULL, NULL, NULL},
   {"StockProxyMenu",          NULL, N_("Proxy"),             NULL, NULL, NULL},
   {"StockRecentCloseTabMenu", NULL, N_("Recent closed tabs"), NULL, NULL, NULL},
   {"StockClipMenu",           NULL, N_("Clip"),        NULL, NULL, NULL},
@@ -2654,13 +2655,10 @@ kz_actions_popup_bookmark_menu_modal (KzWindow *kz, KzBookmark *bookmark,
 
 	extra_menu = gtk_ui_manager_get_widget(kz->menu_merge,
 					       "/BookmarkPopup/AddFeedBookmark");
-	if(extra_menu)
+	if (extra_menu)
 	{
-		GtkWidget *kzembed = KZ_WINDOW_CURRENT_PAGE(kz);
-		if (kzembed)
-			kz_actions_dynamic_append_add_feed_bookmark
-				(KZ_EMBED(kzembed),
-				 GTK_MENU_ITEM(extra_menu));
+		kz_actions_dynamic_append_add_feed_bookmark
+			(kz, GTK_MENU_ITEM(extra_menu));
 	}
 	
 	g_signal_connect(popup_menu, "hide",
@@ -2696,7 +2694,7 @@ kz_actions_insert_smartbookmark (KzWindow *kz, KzBookmark *bookmark,
 	/*
 	 * We should unite KzLocationEntry and KzSmartBookmark.
 	 */
-	if (title && !strncmp(title, "LocationEntry", 13))
+	if (title && g_str_has_prefix(title, "LocationEntry"))
 	{
 		action = gtk_action_group_get_action(kz->actions,
 						     "LocationEntry");
@@ -2743,7 +2741,7 @@ kz_actions_remove_smartbookmark (KzWindow *kz, KzBookmark *bookmark,
 
 	title = kz_bookmark_get_title(child);
 	 
-	if (title && !strncmp(title, "LocationEntry", 13))
+	if (title && g_str_has_prefix(title, "LocationEntry"))
 		return;
 	else
 		action_name = g_strdup_printf("SmartBookmark:%p", child);
@@ -2790,7 +2788,7 @@ kz_actions_update_smartbookmarks (KzWindow *kz, KzBookmark *bookmark)
 		
 		title = kz_bookmark_get_title(child);
 	 
-		if (title && !strncmp(title, "LocationEntry", 13))
+		if (title && g_str_has_prefix(title, "LocationEntry"))
 		{
 			action = gtk_action_group_get_action(kz->actions,
 							     "LocationEntry");
@@ -2873,7 +2871,7 @@ kz_actions_remove_smartbookmarks (KzWindow *kz, KzBookmark *bookmark)
 	    	    !kz_bookmark_is_folder(child)) continue;
 		
 		title = kz_bookmark_get_title(child);
-		if (title && !strncmp(title, "LocationEntry", 13))
+		if (title && g_str_has_prefix(title, "LocationEntry"))
 			action_name = g_strdup("LocationEntry");
 		else
 			action_name = g_strdup_printf("SmartBookmark:%p", child);
@@ -2898,7 +2896,7 @@ kz_actions_remove_smartbookmarks (KzWindow *kz, KzBookmark *bookmark)
 	                g_slist_free(copy);
 		}
 
-		if (title && !strncmp(title, "LocationEntry", 13))
+		if (title && g_str_has_prefix(title, "LocationEntry"))
 		{
 			g_free(action_name);
 			continue;
