@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.78 2005/09/23 12:16:08 tyuyu Exp $
+ *  $Id: kz-bookmark.c,v 1.79 2006/01/15 04:52:24 kous Exp $
  */
 
 #include "kz-bookmark.h"
@@ -32,6 +32,7 @@
 #include "utils.h"
 #include "eggregex.h"
 #include "kz-bookmark-file.h"
+#include "kz-bookmarks-enum-types.h"
 
 enum {
 	INSERT_CHILD_SIGNAL,
@@ -96,24 +97,6 @@ static GQuark lock_quark              = 0;
 static GQuark auto_refresh_quark      = 0;
 static GQuark javascript_quark        = 0;
 
-GType
-kz_bookmark_type_get_type (void)
-{
-	static GType etype = 0;
-	if (etype == 0)
-	{
-		static const GEnumValue values[] = {
-			{ KZ_BOOKMARK_NORMAL,      "KZ_BOOKMARK_NORMAL",      "normal" },
-			{ KZ_BOOKMARK_FOLDER,      "KZ_BOOKMARK_FOLDER",      "folder" },
-			{ KZ_BOOKMARK_PURE_FOLDER, "KZ_BOOKMARK_PURE_FOLDER", "pure-folder" },
-			{ KZ_BOOKMARK_SEPARATOR,   "KZ_BOOKMARK_SEPARATOR",   "separator" },
-			{ 0, NULL, NULL }
-		};
-		etype = g_enum_register_static ("KzBookmarkType", values);
-	}
-	return etype;
-}
-
 
 KZ_OBJECT_GET_TYPE(kz_bookmark, "KzBookmark", KzBookmark,
 		   kz_bookmark_class_init, kz_bookmark_init,
