@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.h,v 1.34 2005/09/23 12:16:08 tyuyu Exp $
+ *  $Id: kz-bookmark.h,v 1.35 2006/01/15 04:52:25 kous Exp $
  */
 
 #ifndef __KZ_BOOKMARK_H__
@@ -35,8 +35,6 @@ G_BEGIN_DECLS
 #define KZ_IS_BOOKMARK_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass),  KZ_TYPE_BOOKMARK))
 #define KZ_BOOKMARK_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj),  KZ_TYPE_BOOKMARK, KzBookmarkClass))
 
-#define KZ_TYPE_BOOKMARK_TYPE		(kz_bookmark_type_get_type())
-
 typedef struct _KzBookmark         KzBookmark;
 typedef struct _KzBookmarkClass    KzBookmarkClass;
 
@@ -79,7 +77,6 @@ struct _KzBookmarkClass
 
 
 /* GType */
-GType		kz_bookmark_type_get_type	(void) G_GNUC_CONST;
 GType		kz_bookmark_get_type		(void) G_GNUC_CONST; 
 
 /* boomark item creating functions */
