@@ -36,7 +36,7 @@ G_BEGIN_DECLS
 
 #define KAZEHAKASE_URI "http://kazehakase.sourceforge.jp/"
 
-#define HISTORY_INDEX "/."PACKAGE"/history_index "
+#define HISTORY_INDEX "/."PACKAGE"/history_index.hest"
 #define HISTORY_DIR   "/."PACKAGE"/history/"
 
 
@@ -63,8 +63,7 @@ extern Migemo         *migemo;
 #endif
 extern gboolean	       is_restoring_session;
 
-extern gboolean        exists_estindex; 
-extern gchar          *estversion;
+extern gboolean        exists_estcmd; 
 
 #define KZ_CONF_GET(s, k, v, t)					\
 	kz_profile_get_value(kz_global_profile,			\
