@@ -538,6 +538,8 @@ kz_embed_reload (KzEmbed *kzembed, KzEmbedReloadFlag flags)
 {
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
 	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->reload);
+	g_return_if_fail(KZ_EMBED_RELOAD_NORMAL <= flags &&
+			 flags <= KZ_EMBED_RELOAD_CHARSET_CHANGE);
 
 	KZ_EMBED_GET_IFACE(kzembed)->reload(kzembed, flags);
 }
