@@ -88,6 +88,9 @@ struct _KzWindow
 	GtkWidget *popup_tablist;
 
 	gboolean   is_closing_all;
+
+	/* extensions */
+	GList *extensions;
 };
 
 struct _KzWindowClass
@@ -128,6 +131,7 @@ void              kz_window_load_url                 (KzWindow    *kz,
 						      const gchar *url);
 void              kz_window_store_state              (KzWindow    *kz);
 void              kz_window_restore_state            (KzWindow    *kz);
+void              kz_window_update_gesture_items     (KzWindow    *kz);
 const gchar      *kz_window_get_title                (KzWindow    *kz);
 const gchar      *kz_window_get_uri                  (KzWindow    *kz);
 
