@@ -54,13 +54,13 @@ struct _EggDropdownToolButtonClass
   void (*menu_activated) (EggDropdownToolButton *button);
 };
 
-GType         egg_dropdown_tool_button_get_type       (void);
+GType         egg_dropdown_tool_button_get_type       (void) G_GNUC_CONST;
 GtkToolItem  *egg_dropdown_tool_button_new            (void);
 GtkToolItem  *egg_dropdown_tool_button_new_from_stock (const gchar *stock_id);
 
 void          egg_dropdown_tool_button_set_menu       (EggDropdownToolButton *button,
-                                                       GtkMenuShell          *menu);
-GtkMenuShell *egg_dropdown_tool_button_get_menu       (EggDropdownToolButton *button);
+                                                       GtkWidget             *menu);
+GtkWidget    *egg_dropdown_tool_button_get_menu       (EggDropdownToolButton *button);
 
 void          egg_dropdown_tool_button_set_arrow_tooltip (EggDropdownToolButton *button,
                                                           GtkTooltips *tooltips,
