@@ -25,7 +25,6 @@
 #include "kazehakase.h"
 #include "kz-window.h"
 #include "kz-gesture.h"
-#include "kz-input-event-box.h"
 
 #define DATA_KEY "KzPrefsGesture::info"
 
@@ -657,7 +656,7 @@ prefs_gesture_create (void)
 	GtkTreeSortable *sortable;
 	GtkTreeViewColumn *col;
 	GtkCellRenderer *renderer;
-	GtkWidget *table, *hbox, *vbox, *button, *arrow, *entry, *ebox;
+	GtkWidget *table, *hbox, *vbox, *button, *arrow, *entry/*, *ebox */;
 	gboolean use_gesture = TRUE;
 
 	self->gesture = NULL;
@@ -762,14 +761,17 @@ prefs_gesture_create (void)
 	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
+#if 0
 	ebox = kz_input_event_box_new();
 	gtk_box_pack_start(GTK_BOX(hbox), ebox, FALSE, FALSE, 2);
 	g_signal_connect(ebox, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(ebox);
+#endif
 
 	table = gtk_table_new(3, 3, TRUE);
-	gtk_container_add(GTK_CONTAINER(ebox), table);
+	gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 2);
+	/*gtk_container_add(GTK_CONTAINER(ebox), table);*/
 	gtk_widget_show(table);
 
 	/* up button */
