@@ -56,6 +56,7 @@ typedef struct _KzPrefsHistory
 	GtkWidget     *optimize_button;
 	GtkWidget     *max_results;
 	GtkWidget     *num_summary;
+	GtkWidget     *except_keyword;
 	gboolean       changed;
 } KzPrefsHistory;
 
@@ -121,9 +122,11 @@ prefs_history_create (void)
 	KzPrefsHistory *prefsui = g_new0(KzPrefsHistory, 1);
 	GtkWidget *main_vbox, *vbox, *hbox, *frame;
 	GtkWidget *label, *check, *spin, *button;
+	GtkWidget *entry;
 	GtkAdjustment *adj;
 	gboolean limit, store_cache = TRUE;
 	gint limit_days, max_results, num_summary;
+	gchar *keyword;
 
 	main_vbox = gtk_vbox_new(FALSE, 0);
 	prefsui->main_vbox = main_vbox;
@@ -263,6 +266,29 @@ prefs_history_create (void)
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(spin);
 
+	/* except keyword */
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
+	gtk_container_add(GTK_CONTAINER(vbox), hbox);
+	gtk_widget_show(hbox);
+
+	label = gtk_label_new_with_mnemonic(_("Except keyword in history search(delimiter for keyword is comma):"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
+	gtk_widget_show(label);
+
+	entry = gtk_entry_new();
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
+	gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 2);
+	gtk_widget_show(entry);
+
+	keyword = KZ_CONF_GET_STR("History", "except_keyword");
+	if(keyword)
+	{
+		gtk_entry_set_text(GTK_ENTRY(entry), keyword);
+		g_free(keyword);
+	}
+	prefsui->except_keyword = entry;
+
 	prefsui->changed = FALSE;
 
 	return main_vbox;
@@ -283,7 +309,11 @@ prefs_history_response (GtkWidget *widget, gint response)
 		GtkAdjustment *adj;
 		gint limit_days, num_summary, max_results;
 		gboolean limit, store_cache;
+		const gchar *keyword;
 
+		keyword = gtk_entry_get_text(GTK_ENTRY(prefsui->except_keyword));
+		KZ_CONF_SET_STR("History", "except_keyword", keyword);
+		
 		if (!prefsui->changed)
 			break;
 
@@ -309,7 +339,7 @@ prefs_history_response (GtkWidget *widget, gint response)
 			(GTK_SPIN_BUTTON(prefsui->num_summary));
 		num_summary = gtk_adjustment_get_value(adj);
 		KZ_CONF_SET("History", "num_summary", num_summary, INT);
-		
+
 		prefsui->changed = FALSE;
 
 		break;
