@@ -129,7 +129,13 @@ cb_focus_new_tab_toggled (GtkToggleButton *button, KzPrefsTab *prefsui)
 #endif
 
 static void
-cb_changed (GtkWidget *widget, KzPrefsTab *prefsui)
+cb_tab_changed (GtkWidget *widget, KzPrefsTab *prefsui)
+{
+	prefsui->changed = TRUE;
+}
+
+static void
+cb_new_tab_changed (GtkWidget *widget, KzPrefsNewTab *prefsui)
 {
 	prefsui->changed = TRUE;
 }
@@ -143,6 +149,14 @@ prefs_tab_destroy (gpointer data)
 	g_free(prefsui);
 }
 
+static void
+prefs_new_tab_destroy (gpointer data)
+{
+	KzPrefsNewTab *prefsui = data;
+
+	g_free(prefsui);
+}
+
 static void
 cb_tab_color_selection (GtkColorButton *cbutton , GdkColor *color)
 {
@@ -206,12 +220,12 @@ prefs_tab_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 2);
 	gtk_widget_set_sensitive(spin, fix);
 	g_signal_connect(spin, "value-changed",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_tab_changed), prefsui);
 	gtk_widget_show(spin);
 
 
 	/*
-	 *  Shiw/Hide
+	 *  Show/Hide
 	 */
 	frame = gtk_frame_new(_("Show/Hide"));
 	gtk_frame_set_label_align(GTK_FRAME(frame), 0.03, 0.5);
@@ -231,7 +245,7 @@ prefs_tab_create (void)
 	KZ_CONF_GET("Tab", "show_favicon", show, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show);
 	g_signal_connect(check, "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_tab_changed), prefsui);
 	gtk_widget_show(check);
 
 	check = gtk_check_button_new_with_mnemonic(_("C_lose button"));
@@ -241,7 +255,7 @@ prefs_tab_create (void)
 	KZ_CONF_GET("Tab", "show_close_button", show, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show);
 	g_signal_connect(check, "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_tab_changed), prefsui);
 	gtk_widget_show(check);
 
 	/*
@@ -265,7 +279,7 @@ prefs_tab_create (void)
 	KZ_CONF_GET("Tab", "wheel_circulation", circulation, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), circulation);
 	g_signal_connect(check, "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_tab_changed), prefsui);
 	gtk_widget_show(check);
 
 	/*
@@ -302,7 +316,7 @@ prefs_tab_create (void)
 				    page_to_return, n_page_to_return, code);
 	g_free(str);
 	g_signal_connect (option_menu, "changed",
-			  G_CALLBACK (cb_changed), prefsui);
+			  G_CALLBACK (cb_tab_changed), prefsui);
 
 	/*
 	 * Tab color selection
@@ -349,7 +363,7 @@ prefs_tab_create (void)
 			  G_CALLBACK (cb_tab_color_selection), 
 			  &prefsui->color[KZ_TAB_LABEL_STATE_NORMAL]);
 	g_signal_connect (cbutton, "color-set",
-			  G_CALLBACK (cb_changed), prefsui);
+			  G_CALLBACK (cb_tab_changed), prefsui);
 	gtk_widget_show(label);
 	gtk_widget_show(cbutton);
 
@@ -375,7 +389,7 @@ prefs_tab_create (void)
 			  G_CALLBACK (cb_tab_color_selection),
 			  &prefsui->color[KZ_TAB_LABEL_STATE_LOADING]);
 	g_signal_connect (cbutton, "color-set",
-			  G_CALLBACK (cb_changed), prefsui);
+			  G_CALLBACK (cb_tab_changed), prefsui);
 	gtk_widget_show(label);
 	gtk_widget_show(cbutton);
 
@@ -401,7 +415,7 @@ prefs_tab_create (void)
 			  G_CALLBACK (cb_tab_color_selection),
 			  &prefsui->color[KZ_TAB_LABEL_STATE_LOADED]);
 	g_signal_connect (cbutton, "color-set",
-			  G_CALLBACK (cb_changed), prefsui);
+			  G_CALLBACK (cb_tab_changed), prefsui);
 	gtk_widget_show(label);
 	gtk_widget_show(cbutton);
 
@@ -422,7 +436,7 @@ prefs_new_tab_create (void)
 	main_vbox = gtk_vbox_new(FALSE, 0);
 	prefsui->main_vbox = main_vbox;
 	g_object_set_data_full(G_OBJECT(main_vbox), DATA_KEY,
-			       prefsui, prefs_tab_destroy);
+			       prefsui, prefs_new_tab_destroy);
 
 	label = kz_prefs_ui_utils_create_title(_("New tab"));
 	gtk_box_pack_start(GTK_BOX(main_vbox), label,
@@ -441,7 +455,7 @@ prefs_new_tab_create (void)
 	KZ_CONF_GET("Tab", "focus_open_new", focus, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), focus);
 	g_signal_connect(check, "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_new_tab_changed), prefsui);
 	gtk_widget_show(check);
 
 	check = gtk_check_button_new_with_mnemonic(_("Move focus to new tab on middle-clicking link"));
@@ -451,7 +465,7 @@ prefs_new_tab_create (void)
 	KZ_CONF_GET("Tab", "focus_mid_click_link", focus, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), focus);
 	g_signal_connect(check, "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_new_tab_changed), prefsui);
 	gtk_widget_show(check);
 
 	check = gtk_check_button_new_with_mnemonic(_("Move _Keyboad focus to location entry when swich to new empty tab"));
@@ -461,7 +475,7 @@ prefs_new_tab_create (void)
 	KZ_CONF_GET("Tab", "focus_loc_ent_new", key_focus, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), key_focus);
 	g_signal_connect(check, "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
+			 G_CALLBACK(cb_new_tab_changed), prefsui);
 	gtk_widget_show(check);
 	
 	/*
@@ -492,7 +506,7 @@ prefs_new_tab_create (void)
 				    n_new_tab_position, code);
 	g_free(str);
 	g_signal_connect (option_menu, "changed",
-			  G_CALLBACK (cb_changed), prefsui);
+			  G_CALLBACK (cb_new_tab_changed), prefsui);
 
 	return main_vbox;
 }
