@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-downloader-sidebar.c,v 1.9 2005/02/13 13:20:37 ikezoe Exp $
+ *  $Id: kz-downloader-sidebar.c,v 1.10 2005/07/10 08:53:37 ikezoe Exp $
  */
 
 #include "kz-downloader-sidebar.h"
@@ -25,8 +25,11 @@
 #include <glib/gi18n.h>
 #include "kazehakase.h"
 #include "gobject-utils.h"
+#if GTK_CHECK_VERSION(2,6,0)
+#define kz_cell_renderer_progress_new gtk_cell_renderer_progress_new
+#else
 #include "kz-cellrendererprogress.h"
-
+#endif
 
 enum {
 	PROP_0,
