@@ -28,7 +28,7 @@
 #include "egg-pixbuf-thumbnail.h"
 
 
-#define ESTRAIER_URI "http://estraier.sourceforge.net/"
+#define ESTRAIER_URI "http://hyperestraier.sourceforge.net/"
 #define DTD   "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">"
 #define HEAD  "<head>\n" \
 	      "  <title>Full-text search in history</title>\n" \
@@ -47,14 +47,16 @@
 		"  </div>\n" \
 		"</div>\n"
 #define FOOTER  "<div class=\"footer\">\n" \
-	        "Powered by <a href=\"%s\">Estraier</a> version %s\n" \
+	        "Powered by <a href=\"%s\">Hyper Estraier</a> version %s\n" \
 		"</div>\n"
 
+static gchar *estsearch_get_version (void);
+
 static gboolean
 execute_search_command(const gchar *search_text, gint *standard_output)
 {
 	gboolean ret;
-	const gchar *estxview = "estxview";
+	const gchar *estsearch_com = "estcmd search -vx ";
 	gchar *command;
 	gint argc;
 	gchar **argv = NULL;
@@ -64,20 +66,46 @@ execute_search_command(const gchar *search_text, gint *standard_output)
 	gchar **split = NULL;
 	gchar *join = NULL;
 	gint max_results = 20, num_summary = 128;
-
-	split = g_strsplit(search_text, "+", -1);
-	if (split)
-	{
-		join = g_strjoinv(" ", split);
-		g_strfreev(split);
-	}
+	gchar *except_word;
+	gchar **except_keywords = NULL;
 
 	KZ_CONF_GET("History", "num_summary", num_summary, INT);
 	KZ_CONF_GET("History", "max_results", max_results, INT);
-	command = g_strdup_printf("%s -snum %d -max %d %s%s %s",
-				  estxview, num_summary, max_results, 
-			          g_get_home_dir(), HISTORY_INDEX,
-			          join);
+
+	split = g_strsplit(search_text, " ", -1);
+	if (split)
+	{
+		join = g_strjoinv(" AND ", split);
+		g_strfreev(split);
+	}
+
+	except_word = KZ_CONF_GET_STR("History", "except_keyword");
+	if (except_word && *except_word)
+	{
+		except_keywords = g_strsplit(except_word, ",", -1);
+		g_free(except_word);
+		except_word = g_strjoinv(" ANDNOT ", except_keywords);
+		g_strfreev(except_keywords);
+
+		command = g_strdup_printf("%s -max %d %s%s %s ANDNOT %s",
+					  estsearch_com,
+					  max_results, 
+					  g_get_home_dir(),
+					  HISTORY_INDEX" ",
+					  join,
+					  except_word);
+		g_free(except_word);
+	}
+	else
+	{
+		command = g_strdup_printf("%s -max %d %s%s %s",
+					  estsearch_com,
+					  max_results, 
+					  g_get_home_dir(),
+					  HISTORY_INDEX" ",
+					  join);
+	}
+
 	if (join)
 		g_free(join);
 
@@ -113,7 +141,7 @@ create_search_result_html (gint out, const gchar *text)
 	gsize length;
 	gchar *title = NULL, *uri = NULL, *date = NULL, *desc = NULL;
 	gchar *cache_link = NULL;
-	gchar *estversion = NULL;
+	gchar *estversion = estsearch_get_version();
 	GString *html;
 
 	io = g_io_channel_unix_new(out);
@@ -131,16 +159,26 @@ create_search_result_html (gint out, const gchar *text)
 
 	while (g_io_channel_read_line(io, &line, &length, NULL, NULL) == G_IO_STATUS_NORMAL)
 	{
-		if (!strncmp(line, "<document", 9))
+		if (g_str_has_prefix(line, "<document"))
 		{
+			size_t len;
+			gchar *dirname = g_strconcat(g_get_home_dir(), 
+						     HISTORY_DIR,
+						     NULL);
+			len = strlen(dirname);
+
+			cache_link = xml_get_attr(line, "uri");
+			uri = create_uri_from_filename(cache_link + 
+						       strlen("file://") + 
+						       len);
 		}
-		else if (!strncmp(line, "</document>", 11))
+		else if (g_str_has_prefix(line, "</document>"))
 		{
 			gchar *thumb_filename, *thumb_uri;
 			thumb_filename = egg_pixbuf_get_thumb_filename(uri,
-						EGG_PIXBUF_THUMB_LARGE);
+								       EGG_PIXBUF_THUMB_LARGE);
 			thumb_uri = g_strdup_printf("history-search:?image=%s",
-						    thumb_filename);	
+						    thumb_filename);
 			g_string_append_printf(html,
 					       CONTENT,
 					       uri,
@@ -159,40 +197,19 @@ create_search_result_html (gint out, const gchar *text)
 			g_free(thumb_filename);
 			g_free(thumb_uri);
 		}
-		else if (!strncmp(line, "<uri>", 5))
+		else if (g_str_has_prefix(line, "<attribute name=\"@title\""))
 		{
-			gchar *dirname, *orig_uri;
-			gchar *link;
-			size_t len;
-			link = xml_get_content(line);
-			cache_link = g_strconcat("file://",
-						 link,
-						 NULL);
-			dirname = g_strconcat(g_get_home_dir(), 
-					      HISTORY_DIR,
-					      NULL);
-			len = strlen(dirname);
-			orig_uri = create_uri_from_filename(link + len);
-			uri = url_decode(orig_uri);
-			g_free(orig_uri);			
-			g_free(dirname);
-			g_free(link);
+			title = xml_get_attr(line, "value");
 		}
-		else if (!strncmp(line, "<title>", 7))
+		else if (g_str_has_prefix(line, "<attribute name=\"@mdate\""))
 		{
-			title = xml_get_content(line);
+			date = xml_get_attr(line, "value");
 		}
-		else if (!strncmp(line, "<date>", 6))
+		else if (g_str_has_prefix(line, "<snippet"))
 		{
-			date = xml_get_content(line);
-		}
-		else if (!strncmp(line, "<estxview", 9))
-		{
-			estversion = xml_get_attr(line, "version");
-		}
-		else if (!strncmp(line, "<summary", 8))
-		{
-			desc = xml_get_content(line);
+			gchar *summary = xml_get_content(line);
+			desc = remove_tag(summary, g_strlen(summary));
+			g_free(summary);
 		}
 		g_free(line);
 	}
@@ -212,7 +229,7 @@ estsearch_get_search_result (const gchar *text)
 	gint out;
 
 	if (!text) return NULL;
-	if (!exists_estindex) return NULL;
+	if (!exists_estcmd) return NULL;
 
 	if (!execute_search_command(text, &out))
 		return NULL;
@@ -223,8 +240,8 @@ estsearch_get_search_result (const gchar *text)
 gboolean
 estsearch_update_index (gpointer data)
 {
-	const gchar *estindex = "estindex register -list - -hsuf \"*\" ";
-	const gchar *estrelate = "estindex relate ";
+	const gchar *estindex_prefix = "estcmd gather -sd -cm -fh ";
+	gchar *index_dir;
 	gchar *command;
 	gchar *filename;
 	gint in;
@@ -234,10 +251,13 @@ estsearch_update_index (gpointer data)
 	GPid pid;
 	GIOChannel *io;
 
-	command = g_strconcat(estindex, 
-			      g_get_home_dir(), HISTORY_INDEX,
-			      g_get_home_dir(), HISTORY_DIR,
+	index_dir = g_strconcat(g_get_home_dir(), HISTORY_INDEX, NULL);
+
+	command = g_strconcat(estindex_prefix,
+			      index_dir,
+			      " - ",	/* read filename from stdin */
 			      NULL);
+	g_free(index_dir);
 
 	g_shell_parse_argv(command,
 			   &argc,
@@ -271,19 +291,35 @@ estsearch_update_index (gpointer data)
 	g_free(filename);
 	g_free(data);
 	
+	return FALSE;
+}
+
+
+gboolean
+estsearch_purge_index (void)
+{
+	const gchar *estpurge = "estcmd purge ";
+	gchar *command;
+	gint argc;
+	gchar **argv = NULL;
+	GSpawnFlags flags;
+	GPid pid;
+
+	/* purge index */
 	flags = G_SPAWN_SEARCH_PATH |
 		G_SPAWN_STDOUT_TO_DEV_NULL;
-	
-	/* score information process */
-	command = g_strconcat(estrelate, 
-			      g_get_home_dir(), HISTORY_INDEX,
+	command = g_strconcat(estpurge,
+			      g_get_home_dir(),
+			      HISTORY_INDEX,
 			      NULL);
 
 	g_shell_parse_argv(command,
 			   &argc,
 			   &argv,
 			   NULL);
-
+	flags = G_SPAWN_SEARCH_PATH |
+		G_SPAWN_STDOUT_TO_DEV_NULL;
+	
 	g_spawn_async(NULL,
 		      argv,
 		      NULL,
@@ -292,85 +328,17 @@ estsearch_update_index (gpointer data)
 		      NULL,
 		      &pid,
 		      NULL);
+
 	g_strfreev(argv);
 	g_free(command);
 
 	return FALSE;
 }
 
-
-gboolean
-estsearch_purge_index (gchar **files)
-{
-	const gchar *estpurge = "estindex purge ";
-	gchar *command;
-	gint argc, in, i = 0;
-	gchar **argv = NULL;
-	GSpawnFlags flags;
-	GPid pid;
-	GIOChannel *io;
-	gboolean listflag = FALSE;
-
-	listflag = (g_ascii_strcasecmp(estversion, "1.2.18") >= 0);
-	
-	/* purge index */
-	flags = G_SPAWN_SEARCH_PATH |
-		G_SPAWN_STDOUT_TO_DEV_NULL;
-	if (listflag)
-	{
-		command = g_strconcat(estpurge, "-list - ",
-				      g_get_home_dir(), HISTORY_INDEX,
-				      NULL);
-	}
-	else
-	{
-		command = g_strconcat(estpurge,
-				      g_get_home_dir(), HISTORY_INDEX,
-				      NULL);
-	}
-
-	g_shell_parse_argv(command,
-			   &argc,
-			   &argv,
-			   NULL);
-
-	g_spawn_async_with_pipes(NULL,
-		      		 argv,
-				 NULL,
-		   		 flags,
-		      		 NULL,
-		      		 NULL,
-		      		 &pid,
-				 &in,
-				 NULL,
-				 NULL,
-		      		 NULL);
-	g_strfreev(argv);
-	g_free(command);
-
-	/* set filename to add index */
-	if (listflag && !files)
-	{
-		while (files[i])
-		{
-			io = g_io_channel_unix_new(in);
-			g_io_channel_set_encoding(io, NULL, NULL);
-			g_io_channel_write_chars(io,
-						 files[i], g_strlen(files[i]),
-						 NULL, NULL);
-			g_io_channel_shutdown(io, TRUE, NULL);
-			g_io_channel_unref(io);
-			i++;
-		}
-	}
-
-	return FALSE;
-}
-
 GPid
 estsearch_optimize_index (void)
 {
-	const gchar *estoptimize = "estindex optimize "; 
+	const gchar *estoptimize = "estcmd optimize "; 
 	gchar *command;
 	gint argc;
 	gchar **argv = NULL;
@@ -403,11 +371,12 @@ estsearch_optimize_index (void)
 	return pid;
 }
 
-gchar *
+static gchar*
 estsearch_get_version (void)
 {
-	gchar *version, *find;
-	const gchar *estsiutil = "estsiutil version";
+	gchar *version, *estcmd_output;
+	gchar **splited_estcmd_output = NULL;
+	const gchar *estversion = "estcmd version";
 	gint argc;
 	gchar **argv = NULL;
 	GSpawnFlags flags;
@@ -417,11 +386,9 @@ estsearch_get_version (void)
 	GIOChannel *io;
 	gsize length;
 
-	find = g_find_program_in_path("estsiutil");
-	if (!find) return NULL;
-	g_free(find);
-
-	g_shell_parse_argv(estsiutil,
+	if (!exists_estcmd) return NULL;
+	
+	g_shell_parse_argv(estversion,
 			   &argc,
 			   &argv,
 			   NULL);
@@ -443,14 +410,19 @@ estsearch_get_version (void)
 
 	io = g_io_channel_unix_new(out);
 	g_io_channel_set_encoding(io, NULL, NULL);
-	g_io_channel_read_line(io, &version, &length, NULL, NULL);
+	g_io_channel_read_line(io, &estcmd_output, &length, NULL, NULL);
 	g_io_channel_shutdown(io, TRUE, NULL);
 	g_io_channel_unref(io);
 
+	splited_estcmd_output = g_strsplit(estcmd_output, " ", -1);
+	version = g_strdup(splited_estcmd_output[2]);
+
+	g_free(estcmd_output);
+	g_strfreev(splited_estcmd_output);
+
 	return version;
 }
 
-
 static KzBookmark *
 create_search_result_bookmark (gint out, const gchar *text)
 {
@@ -467,10 +439,7 @@ create_search_result_bookmark (gint out, const gchar *text)
 	
 	while (g_io_channel_read_line(io, &line, &length, NULL, NULL) == G_IO_STATUS_NORMAL)
 	{
-		if (!strncmp(line, "<document", 9))
-		{
-		}
-		else if (!strncmp(line, "</document>", 11))
+		if (g_str_has_prefix(line, "</document>"))
 		{
 			KzBookmark *child;
 			child = kz_bookmark_new_with_attrs(title, uri, desc);
@@ -480,27 +449,27 @@ create_search_result_bookmark (gint out, const gchar *text)
 			g_free(title);
 			g_free(uri);
 		}
-		else if (!strncmp(line, "<uri>", 5))
+		else if (g_str_has_prefix(line, "<uri>"))
 		{
 			gchar *dirname, *orig_uri;
 			gchar *link;
 			size_t len;
-			link = xml_get_content(line);
+			link = xml_get_attr(line, "uri");
 			dirname = g_strconcat(g_get_home_dir(), 
 					      HISTORY_DIR,
 					      NULL);
 			len = strlen(dirname);
-			orig_uri = create_uri_from_filename(link + len);
+			orig_uri = create_uri_from_filename(link + strlen("file://") + len);
 			uri = url_decode(orig_uri);
 			g_free(orig_uri);			
 			g_free(dirname);
 			g_free(link);
 		}
-		else if (!strncmp(line, "<title>", 7))
+		else if (g_str_has_prefix(line, "<title>"))
 		{
 			title = xml_get_content(line);
 		}
-		else if (!strncmp(line, "<summary", 8))
+		else if (g_str_has_prefix(line, "<summary"))
 		{
 			gchar *summary = xml_get_content(line);
 			desc = remove_tag(summary, g_strlen(summary));
@@ -519,7 +488,7 @@ estsearch_get_search_result_bookmark (const gchar *text)
 	gint out;
 
 	if (!text) return NULL;
-	if (!exists_estindex) return NULL;
+	if (!exists_estcmd) return NULL;
 
 	if (!execute_search_command(text, &out))
 		return NULL;
@@ -527,3 +496,52 @@ estsearch_get_search_result_bookmark (const gchar *text)
 	return create_search_result_bookmark(out, text);
 }
 
+void
+estsearch_make_index(void)
+{
+	const gchar *estgather = "estcmd gather -fh -sd "; 
+	gchar *command;
+	gint argc;
+	gchar **argv = NULL;
+	GSpawnFlags flags;
+	GPid pid;
+	
+	command = g_strconcat(estgather, 
+			      g_get_home_dir(),
+			      HISTORY_INDEX" ",
+			      g_get_home_dir(),
+			      HISTORY_DIR,
+			      NULL);
+
+	g_shell_parse_argv(command,
+			   &argc,
+			   &argv,
+			   NULL);
+	flags = G_SPAWN_SEARCH_PATH |
+		G_SPAWN_STDOUT_TO_DEV_NULL;
+	
+	g_spawn_async(NULL,
+		      argv,
+		      NULL,
+		      flags,
+		      NULL,
+		      NULL,
+		      &pid,
+		      NULL);
+	g_strfreev(argv);
+	g_free(command);
+}
+
+gboolean
+estsearch_exist_index_dir(void)
+{
+	gchar *index_dir;
+	gboolean exist = FALSE;
+
+	index_dir = g_build_filename(g_get_home_dir(),
+			HISTORY_INDEX, NULL);
+	exist = g_file_test(index_dir, G_FILE_TEST_IS_DIR);
+	g_free(index_dir);
+
+	return exist;
+}
